@@ -28,5 +28,5 @@ class Offer(BaseModel):
 
 
 @app.post("/offers/")
-async def create_offer(*, offer: Offer):
+async def create_offer(offer: Offer):
     return offer
