@@ -3,10 +3,6 @@
 set -e
 set -x
 
-# Remove temporary DB
-if [ -f ./test.db ]; then
-    rm ./test.db
-fi
 bash ./scripts/lint.sh
 # Check README.md is up to date
 diff --brief docs/en/docs/index.md README.md
