@@ -1,7 +1,7 @@
 from functools import partial
 
 from fastapi import FastAPI
-from starlette.testclient import TestClient
+from fastapi.testclient import TestClient
 
 
 def main(some_arg, q: str = None):
