@@ -15,11 +15,11 @@ client = TestClient(app)
 
 def test_default_param_query_none():
     response = client.get("/items/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"q": None}
 
 
 def test_default_param_query():
     response = client.get("/items/?q=foo")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"q": "foo"}
